@@ -10,10 +10,12 @@
 #include "kitchensink/kiterror.h"
 #include "kitchensink/internal/kitlibstate.h"
 #include "kitchensink/internal/utils/kithelpers.h"
-#include "kitchensink/internal/utils/kitbuffer.h"
 #include "kitchensink/internal/audio/kitaudio.h"
 #include "kitchensink/internal/utils/kitringbuffer.h"
-#include "kitchensink/internal/utils/kitlog.h"
+
+#if LIBAVUTIL_VERSION_MAJOR < 58
+#define OLD_CHANNEL_LAYOUT
+#endif
 
 #define KIT_AUDIO_SYNC_THRESHOLD 0.05
 
@@ -29,7 +31,7 @@ typedef struct Kit_AudioPacket {
 } Kit_AudioPacket;
 
 
-Kit_AudioPacket* _CreateAudioPacket(const char* data, size_t len, double pts) {
+static Kit_AudioPacket* _CreateAudioPacket(const char* data, size_t len, double pts) {
     Kit_AudioPacket *p = calloc(1, sizeof(Kit_AudioPacket));
     p->rb = Kit_CreateRingBuffer(len);
     Kit_WriteRingBuffer(p->rb, data, len);
@@ -37,7 +39,7 @@ Kit_AudioPacket* _CreateAudioPacket(const char* data, size_t len, double pts) {
     return p;
 }
 
-enum AVSampleFormat _FindAVSampleFormat(int format) {
+static enum AVSampleFormat _FindAVSampleFormat(int format) {
     switch(format) {
         case AUDIO_U8: return AV_SAMPLE_FMT_U8;
         case AUDIO_S16SYS: return AV_SAMPLE_FMT_S16;
@@ -46,7 +48,8 @@ enum AVSampleFormat _FindAVSampleFormat(int format) {
     }
 }
 
-int64_t _FindAVChannelLayout(int channels) {
+#ifdef OLD_CHANNEL_LAYOUT
+static int64_t _FindAVChannelLayout(int channels) {
     switch(channels) {
         case 1: return AV_CH_LAYOUT_MONO;
         case 2: return AV_CH_LAYOUT_STEREO;
@@ -54,15 +57,30 @@ int64_t _FindAVChannelLayout(int channels) {
     }
 }
 
-int _FindChannelLayout(uint64_t channel_layout) {
+static int _FindChannelLayout(uint64_t channel_layout) {
     switch(channel_layout) {
         case AV_CH_LAYOUT_MONO: return 1;
         case AV_CH_LAYOUT_STEREO: return 2;
         default: return 2;
     }
 }
+#else
+static void _FindAVChannelLayout(AVChannelLayout *layout, int channels) {
+    switch(channels) {
+        case 1: *layout = (AVChannelLayout)AV_CHANNEL_LAYOUT_MONO;
+        case 2: *layout = (AVChannelLayout)AV_CHANNEL_LAYOUT_STEREO;
+        default: *layout = (AVChannelLayout)AV_CHANNEL_LAYOUT_STEREO;
+    }
+}
 
-int _FindBytes(enum AVSampleFormat fmt) {
+static int _FindChannelLayout(const AVChannelLayout *channel_layout) {
+    if (channel_layout->nb_channels > 2)
+        return 2;
+    return channel_layout->nb_channels;
+}
+#endif
+
+static int _FindBytes(enum AVSampleFormat fmt) {
     switch(fmt) {
         case AV_SAMPLE_FMT_U8P:
         case AV_SAMPLE_FMT_U8:
@@ -75,7 +93,7 @@ int _FindBytes(enum AVSampleFormat fmt) {
     }
 }
 
-int _FindSDLSampleFormat(enum AVSampleFormat fmt) {
+static int _FindSDLSampleFormat(enum AVSampleFormat fmt) {
     switch(fmt) {
         case AV_SAMPLE_FMT_U8P:
         case AV_SAMPLE_FMT_U8:
@@ -88,7 +106,7 @@ int _FindSDLSampleFormat(enum AVSampleFormat fmt) {
     }
 }
 
-int _FindSignedness(enum AVSampleFormat fmt) {
+static int _FindSignedness(enum AVSampleFormat fmt) {
     switch(fmt) {
         case AV_SAMPLE_FMT_U8P:
         case AV_SAMPLE_FMT_U8:
@@ -104,84 +122,6 @@ static void free_out_audio_packet_cb(void *packet) {
     free(p);
 }
 
-#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(57, 48, 101)
-static int dec_decode_audio_cb(Kit_Decoder *dec, AVPacket *in_packet) {
-    assert(dec != NULL);
-
-    if(in_packet == NULL) {
-        return 0;
-    }
-
-    Kit_AudioDecoder *audio_dec = dec->userdata;
-    int frame_finished;
-    int len;
-    int len2;
-    int dst_linesize;
-    int dst_nb_samples;
-    int dst_bufsize;
-    double pts;
-    unsigned char **dst_data;
-    Kit_AudioPacket *out_packet = NULL;
-
-    // Decode as long as there is data
-    while(in_packet->size > 0) {
-        len = avcodec_decode_audio4(dec->codec_ctx, audio_dec->scratch_frame, &frame_finished, in_packet);
-        if(len < 0) {
-            return 0;
-        }
-
-        if(frame_finished) {
-            dst_nb_samples = av_rescale_rnd(
-                audio_dec->scratch_frame->nb_samples,
-                dec->output.samplerate,  // Target samplerate
-                dec->codec_ctx->sample_rate,  // Source samplerate
-                AV_ROUND_UP);
-
-            av_samples_alloc_array_and_samples(
-                &dst_data,
-                &dst_linesize,
-                dec->output.channels,
-                dst_nb_samples,
-                _FindAVSampleFormat(dec->output.format),
-                0);
-
-            len2 = swr_convert(
-                audio_dec->swr,
-                dst_data,
-                audio_dec->scratch_frame->nb_samples,
-                (const unsigned char **)audio_dec->scratch_frame->extended_data,
-                audio_dec->scratch_frame->nb_samples);
-
-            dst_bufsize = av_samples_get_buffer_size(
-                &dst_linesize,
-                dec->output.channels,
-                len2,
-                _FindAVSampleFormat(dec->output.format), 1);
-
-            // Get presentation timestamp
-#ifndef FF_API_FRAME_GET_SET
-            pts = av_frame_get_best_effort_timestamp(audio_dec->scratch_frame);
-#else
-            pts = audio_dec->scratch_frame->best_effort_timestamp;
-#endif
-            pts *= av_q2d(dec->format_ctx->streams[dec->stream_index]->time_base);
-
-            // Lock, write to audio buffer, unlock
-            out_packet = _CreateAudioPacket(
-                (char*)dst_data[0], (size_t)dst_bufsize, pts);
-            Kit_WriteDecoderOutput(dec, out_packet);
-
-            // Free temps
-            av_freep(&dst_data[0]);
-            av_freep(&dst_data);
-        }
-
-        in_packet->size -= len;
-        in_packet->data += len;
-    }
-    return 0;
-}
-#else
 static void dec_read_audio(const Kit_Decoder *dec) {
     const Kit_AudioDecoder *audio_dec = dec->userdata;
     int len;
@@ -245,7 +185,7 @@ static int dec_decode_audio_cb(Kit_Decoder *dec, AVPacket *in_packet) {
     assert(in_packet != NULL);
 
     // Try to clear the buffer first. We might have too much content in the ffmpeg buffer,
-    /// so we want to clear it of outgoing data if we can.
+    // so we want to clear it of outgoing data if we can.
     dec_read_audio(dec);
 
     // Write packet to the decoder for handling.
@@ -253,11 +193,10 @@ static int dec_decode_audio_cb(Kit_Decoder *dec, AVPacket *in_packet) {
         return 1;
     }
 
-    // Some input data was put in succesfully, so try again to get frames.
+    // Some input data was put in successfully, so try again to get frames.
     dec_read_audio(dec);
     return 0;
 }
-#endif
 
 static void dec_close_audio_cb(Kit_Decoder *dec) {
     if(dec == NULL) return;
@@ -308,12 +247,17 @@ Kit_Decoder* Kit_CreateAudioDecoder(const Kit_Source *src, int stream_index) {
     Kit_OutputFormat output;
     memset(&output, 0, sizeof(Kit_OutputFormat));
     output.samplerate = dec->codec_ctx->sample_rate;
+#ifdef OLD_CHANNEL_LAYOUT
     output.channels = _FindChannelLayout(dec->codec_ctx->channel_layout);
+#else
+    output.channels = _FindChannelLayout(&dec->codec_ctx->ch_layout);
+#endif
     output.bytes = _FindBytes(dec->codec_ctx->sample_fmt);
     output.is_signed = _FindSignedness(dec->codec_ctx->sample_fmt);
     output.format = _FindSDLSampleFormat(dec->codec_ctx->sample_fmt);
 
     // Create resampler
+#ifdef OLD_CHANNEL_LAYOUT
     audio_dec->swr = swr_alloc_set_opts(
         NULL,
         _FindAVChannelLayout(output.channels), // Target channel layout
@@ -323,6 +267,23 @@ Kit_Decoder* Kit_CreateAudioDecoder(const Kit_Source *src, int stream_index) {
         dec->codec_ctx->sample_fmt, // Source fmt
         dec->codec_ctx->sample_rate, // Source samplerate
         0, NULL);
+#else
+    AVChannelLayout layout;
+    _FindAVChannelLayout(&layout, output.channels);
+     int swr_ok = swr_alloc_set_opts2(
+            &audio_dec->swr,
+            &layout, // Target channel layout
+            _FindAVSampleFormat(output.format), // Target fmt
+            output.samplerate, // Target sample rate
+            &dec->codec_ctx->ch_layout, // Source channel layout
+            dec->codec_ctx->sample_fmt, // Source fmt
+            dec->codec_ctx->sample_rate, // Source sample rate
+            0, NULL);
+     if (swr_ok != 0) {
+         Kit_SetError("Unable to initialize audio resampler context");
+         goto EXIT_3;
+     }
+#endif
 
     if(swr_init(audio_dec->swr) != 0) {
         Kit_SetError("Unable to initialize audio resampler context");
@@ -397,7 +358,7 @@ int Kit_GetAudioDecoderData(Kit_Decoder *dec, unsigned char *buf, int len) {
     dec->clock_pos = packet->pts;
 
     // If ringbuffer is cleared, kill packet and advance buffer.
-    // Otherwise forward the pts value for the current packet.
+    // Otherwise, forward the pts value for the current packet.
     if(Kit_GetRingBufferLength(packet->rb) == 0) {
         Kit_AdvanceDecoderOutput(dec);
         free_out_audio_packet_cb(packet);
