@@ -17,7 +17,7 @@ Kit_Decoder* Kit_CreateDecoder(const Kit_Source *src, int stream_index,
                                int thread_count) {
     assert(src != NULL);
     assert(out_b_size > 0);
-    assert(thread_count > 0);
+    assert(thread_count >= 0);
 
     AVCodecContext *codec_ctx = NULL;
     AVDictionary *codec_opts = NULL;
@@ -40,11 +40,7 @@ Kit_Decoder* Kit_CreateDecoder(const Kit_Source *src, int stream_index,
     }
 
     // Find audio decoder
-#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(57, 48, 101)
-    codec = avcodec_find_decoder(format_ctx->streams[stream_index]->codec->codec_id);
-#else
     codec = avcodec_find_decoder(format_ctx->streams[stream_index]->codecpar->codec_id);
-#endif
     if(codec == NULL) {
         Kit_SetError("No suitable decoder found for stream %d", stream_index);
         goto EXIT_1;
@@ -58,29 +54,25 @@ Kit_Decoder* Kit_CreateDecoder(const Kit_Source *src, int stream_index,
     }
 
     // Copy params
-#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(57, 48, 101)
-    if(avcodec_copy_context(codec_ctx, format_ctx->streams[stream_index]->codec) != 0)
-#else
-    if(avcodec_parameters_to_context(codec_ctx, format_ctx->streams[stream_index]->codecpar) < 0)
-#endif
-    {
+    if(avcodec_parameters_to_context(codec_ctx, format_ctx->streams[stream_index]->codecpar) < 0) {
         Kit_SetError("Unable to copy codec context for stream %d", stream_index);
         goto EXIT_2;
     }
 
-    // Required by ffmpeg for now when using the new API.
-#if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(57, 48, 101)
     codec_ctx->pkt_timebase = format_ctx->streams[stream_index]->time_base;
-#endif
 
-    // Set thread count
+    // Set threading, if possible
     codec_ctx->thread_count = thread_count;
-    codec_ctx->thread_type = FF_THREAD_SLICE|FF_THREAD_FRAME;
+    if(codec->capabilities | AV_CODEC_CAP_FRAME_THREADS) {
+        codec_ctx->thread_type = FF_THREAD_FRAME;
+    } else if(codec->capabilities | AV_CODEC_CAP_SLICE_THREADS) {
+        codec_ctx->thread_type = FF_THREAD_SLICE;
+    } else {
+        codec_ctx->thread_count = 1;  // Disable threading
+    }
 
-    // This is required for ass_process_chunk() support
-#if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(57, 25, 100)
+    // This is required for ass_process_chunk()
     av_dict_set(&codec_opts, "sub_text_format", "ass", 0);
-#endif
 
     // Open the stream
     if(avcodec_open2(codec_ctx, codec, &codec_opts) < 0) {
