@@ -1,4 +1,4 @@
-#include <stdlib.h>
+#include <stddef.h>
 #include "kitchensink/internal/kitlibstate.h"
 
 static Kit_LibraryState _librarystate = {0, 1, 0, 3, 64, 64, NULL, NULL};
