@@ -11,8 +11,8 @@
 
 static void _libass_msg_callback(int level, const char *fmt, va_list va, void *data) {}
 
-static int max(int a, int b) { return a > b ? a : b; }
-static int min(int a, int b) { return a < b ? a : b; }
+static int Kit_max(int a, int b) { return a > b ? a : b; }
+static int Kit_min(int a, int b) { return a < b ? a : b; }
 
 int Kit_InitASS(Kit_LibraryState *state) {
 #ifdef USE_DYNAMIC_LIBASS
@@ -90,19 +90,19 @@ void Kit_SetHint(Kit_HintType type, int value) {
     Kit_LibraryState *state = Kit_GetLibraryState();
     switch(type) {
         case KIT_HINT_THREAD_COUNT:
-            state->thread_count =  max(value, 0);
+            state->thread_count =  Kit_max(value, 0);
             break;
         case KIT_HINT_FONT_HINTING:
-            state->font_hinting = max(min(value, KIT_FONT_HINTING_COUNT), 0);
+            state->font_hinting = Kit_max(Kit_min(value, KIT_FONT_HINTING_COUNT), 0);
             break;
         case KIT_HINT_VIDEO_BUFFER_FRAMES:
-            state->video_buf_frames = max(value, 1);
+            state->video_buf_frames = Kit_max(value, 1);
             break;
         case KIT_HINT_AUDIO_BUFFER_FRAMES:
-            state->audio_buf_frames = max(value, 1);
+            state->audio_buf_frames = Kit_max(value, 1);
             break;
         case KIT_HINT_SUBTITLE_BUFFER_FRAMES:
-            state->subtitle_buf_frames = max(value, 1);
+            state->subtitle_buf_frames = Kit_max(value, 1);
             break;
     }
 }
